@@ -1,3 +1,3 @@
 from .start import scorecard
 
-h=scorecard()
\ No newline at end of file
+# h=scorecard()
\ No newline at end of file
